==================================
:code:`Trakt['users/*/following']`
==================================

.. automodule:: trakt.interfaces.users.following

  .. autoclass:: UsersFollowingInterface
    :members: get
    :undoc-members:
